package WebifyImages;

# static variables
$WebifyImages::CC_ICON = '~/scripts/webifyImages/cc80x15.png';
$WebifyImages::URL_FONT = '~/scripts/webifyImages/hanshand.ttf';

# function to addin the watermark image
# arguments: the file names to modify
sub insertCCIcon{
  print "\nInserting CC Icon:\n";
  print "------------------\n\n";
  foreach my $image (@_){
    print "processing file $image\n";
    `composite -gravity southwest -geometry +5+5  ${WebifyImages::CC_ICON} $image $image`;
  }
}

# function to add in the URL
# arguments: the file names to modify
sub insertUrl{
  print "\nInserting URL:\n";
  print "--------------\n\n";
  foreach my $image(@_){
    print "processing file $image\n";
    `convert $image -fill white -pointsize 17 -font ${WebifyImages::URL_FONT} -gravity southeast  -annotate +7-3 'www.bartbusschots.ie' $image`;
  }
}

# function to re-size images to a max dimension of 800
# arguments: the file names to modify
sub resizeImages{
  print "\nResizing Images:\n";
  print "----------------\n\n";
  foreach my $image(@_){
    print "processing file $image\n";
    `mogrify -size 3008x3008 -thumbnail 800x800 '$image'`;
  }
}

# function to re-size images to any max dimension
# arguments: 
# 1) the max dimension in px
# 2) the file names to modify
sub scaleImages{
  my $maxDim = shift;
  my $dim = $maxDim.'x'.$maxDim;
  print "\nResizing Images:\n";
  print "----------------\n\n";
  foreach my $image(@_){
    print "processing file $image\n";
    `mogrify -size 3008x3008 -thumbnail $dim '$image'`;
  }
}

# function to add a credit into an image
# Arguments:
# 1) the image name
# 2) the name to credit
sub insertCredit{
  my $image = shift;
  my $credit = shift;
  print "Crediting $credit on the image $image\n";
  `convert $image -fill white -pointsize 17 -font ${WebifyImages::URL_FONT} -gravity southeast -annotate +7+18 'Credit: $credit' $image`;

}

# function to add a caption into an image
# Arguments:
# 1) the image name
# 2) the caption
sub insertCaption{
  my $image = shift;
  my $caption = shift;
  print "Adding the caption \"$caption\" to the image $image\n";
  `convert $image -fill white -pointsize 17 -font ${WebifyImages::URL_FONT} -gravity southeast -annotate +7+18 '$caption' $image`;

}

#mogrify -size 1024x1024 -auto-orient -thumbnail 250x90  '*.jpg'

# fucntion to double-frame pics for adding to Flickr etc
# Arguments:
# 1) the image to frame
# 2) The title to use for the image
sub fineArtFrame{
	$image = shift;
	$title = shift;
	`convert -border 1x1 -bordercolor "#FFFFFF" $image $image`;
	`convert -border 40x40 -bordercolor "#000000" $image $image`;
	`composite -gravity southwest -geometry +12+12  ${WebifyImages::CC_ICON} $image $image`;
	`convert $image -fill white -pointsize 17 -font ${WebifyImages::URL_FONT} -gravity southeast  -annotate +12+2 'www.bartbusschots.ie' $image`;
	`convert $image -fill white -pointsize 20 -font ${WebifyImages::URL_FONT} -gravity south  -annotate +0+3 '$title' $image`;
	`convert -border 1x1 -bordercolor "#FFFFFF" $image $image`;
}

my $perl_is_dumb = 1;
